@@ -4,26 +4,26 @@ from pzflow import examples
 from pzflow import Flow
 
 
-def test_load_two_moons_data():
-    data = examples.two_moons_data()
+def test_get_twomoons_data():
+    data = examples.get_twomoons_data()
     assert isinstance(data, pd.DataFrame)
     assert data.shape == (10000, 2)
 
 
-def test_load_galaxy_data():
-    data = examples.galaxy_data()
+def test_get_galaxy_data():
+    data = examples.get_galaxy_data()
     assert isinstance(data, pd.DataFrame)
     assert data.shape == (100000, 7)
 
 
-def test_load_city_data():
-    data = examples.city_data()
+def test_get_city_data():
+    data = examples.get_city_data()
     assert isinstance(data, pd.DataFrame)
     assert data.shape == (47966, 5)
 
 
-def test_load_example_flow():
-    flow = examples.example_flow()
+def test_get_example_flow():
+    flow = examples.get_example_flow()
     assert isinstance(flow, Flow)
     assert isinstance(flow.info, str)
 
